@@ -2,6 +2,18 @@ const path = require('path');
 const $ = require('jquery');
 require("jquery-ui");
 
+global.__VP_CSS_LOADER__ = function(path) {
+    return path + '.css';
+}
+
+global.__VP_TEXT_LOADER__ = function(path) {
+    return '!!text-loader!' + path;
+}
+
+global.__VP_RAW_LOADER__ = function(path) {
+    return path;
+}
+
 global.$ = $;
 global.vpBase = path.resolve(__dirname, "lib") + '/';
 module.exports = [{
