@@ -1,5 +1,5 @@
 define([
-    'vp_base/css/component/instanceEditor.css', // LAB: css! to css-loader
+    'vp_base/css/component/instanceEditor.css', // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
